@@ -3,7 +3,7 @@ BEGIN {
   $SyForm::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: Easy form management
-$SyForm::VERSION = '0.102';
+$SyForm::VERSION = '0.103';
 use Moo;
 use Tie::IxHash;
 use Module::Runtime qw( use_module );
@@ -105,7 +105,7 @@ SyForm - Easy form management
 
 =head1 VERSION
 
-version 0.102
+version 0.103
 
 =head1 SYNOPSIS
 
@@ -155,30 +155,7 @@ version 0.102
 
 =head1 DESCRIPTION
 
-B<SyForm> is developed for L<SyContent|https://sycontent.de/>.
-
-B<WARNING:> So far the development of B<SyForm> is concentrating on delivering
-the featureset B<SyContent> requires. I don't advice using it without staying
-in contact with me (B<Getty>) at B<#sycontent> on B<irc.perl.org>. While the
-core API will stay stable, the way how to extend the system will change with
-the time.
-
-=encoding utf8
-
-=head1 SUPPORT
-
-IRC
-
-  Join #sycontent on irc.perl.org. Highlight Getty for fast reaction :).
-
-Repository
-
-  http://github.com/SyContent/SyForm
-  Pull request and additional contributors are welcome
-
-Issue Tracker
-
-  http://github.com/SyContent/SyForm/issues
+B<Deprecated> Please do not use!
 
 =head1 AUTHOR
 
